@@ -560,8 +560,12 @@ class FluxAgent:
             except Exception as e:
                 log.error(e)
             plugin = plugin.plugin
+            # tidy up
             if isinstance(plugin, FluxVaultExtensions):
                 if plugin.required_packages:
+                    log.info(
+                        f"Installing the following packages: {plugin.required_packages}"
+                    )
                     try:
                         subprocess.run(
                             [sys.executable, "-m", "pip", "install"]
@@ -583,8 +587,8 @@ class FluxAgent:
                             log.error(
                                 f"Bad runner... plugin is not a FluxVault extensions"
                             )
-                else:
-                    self.extensions.add_plugin(plugin)
+
+                self.extensions.add_plugin(plugin)
                 log.info(f"Plugin {plugin.plugin_name} loaded")
             else:
                 log.error("Plugin load error... skipping")
